==> snEADy1.0.zip: src/de/farafin/snEADy/control/GaphixStuff/I_GraphixConstants.java <==
/*
 * Created on 24.02.2005
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
package de.farafin.snEADy.control.GaphixStuff;


import java.awt.Color;
import java.awt.event.KeyEvent;
import java.io.File;

import de.farafin.snEADy.communication.I_PlayFieldConstants;

/**
 * @author lars & roland
 *
 * TODO To change the template for this generated type comment go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
public interface I_GraphixConstants{
    public static final char    C_NOTHING=0,
								C_WALL=I_PlayFieldConstants.WALL ,
							    C_FLOOR=I_PlayFieldConstants.FREE,
							    C_EXIT=I_PlayFieldConstants.EXIT,
							    C_WALL_S=1,
							    C_WALLCORNER_NW_CC=1,
							    C_WALLCORNER_NW_CV=2,
							    C_WALLCORNER_N=3,
							    C_WALLCORNER_NE_CC=4,
							    C_WALLCORNER_NE_CV=5,
							    C_WALLCORNER_E=6,
							    C_WALLCORNER_SE_CC=7,
							    C_WALLCORNER_SE_CV=8,
							    C_WALLCORNER_S=9,
							    C_WALLCORNER_SW_CC=10,
							    C_WALLCORNER_SW_CV=11,
							    C_WALLCORNER_W=12,
							    C_WALL_E=12,
							    C_PLAYERH_S=13,
							    C_PLAYERH01=13,
							    C_PLAYERH02=14,
							    C_PLAYERH03=15,
							    C_PLAYERH04=16,
							    C_PLAYERH05=17,
							    C_PLAYERH06=18,
							    C_PLAYERH07=19,
							    C_PLAYERH08=20,
							    C_PLAYERH09=21,
							    C_PLAYERH10=22,
							    C_PLAYERH_E=22,
							    C_EXITO=23,
							    C_PLAYER_S=I_PlayFieldConstants.PLAYER_0,
							    C_PLAYER01=I_PlayFieldConstants.PLAYER_0,
							    C_PLAYER02=I_PlayFieldConstants.PLAYER_1,
							    C_PLAYER03=I_PlayFieldConstants.PLAYER_2,
							    C_PLAYER04=I_PlayFieldConstants.PLAYER_3,
							    C_PLAYER05=I_PlayFieldConstants.PLAYER_4,
							    C_PLAYER06=I_PlayFieldConstants.PLAYER_5,
							    C_PLAYER07=I_PlayFieldConstants.PLAYER_6,
							    C_PLAYER08=I_PlayFieldConstants.PLAYER_7,
							    C_PLAYER09=I_PlayFieldConstants.PLAYER_8,
							    C_PLAYER10=I_PlayFieldConstants.PLAYER_9,
							    C_PLAYER_E=I_PlayFieldConstants.PLAYER_9,
							    C_GOODY_S=I_PlayFieldConstants.LENGTH,
							    C_GOODY_SPEED=I_PlayFieldConstants.SPEED,
							    C_GOODY_LENGTH=I_PlayFieldConstants.LENGTH,
							    C_GOODY_POINTS=I_PlayFieldConstants.SHORT,
							    C_GOODY_E=I_PlayFieldConstants.SHORT,
							    C_UNKNOWN=255,
								C_END=256;
	
    public static final char	M_BG=1,
								M_TABOPEN=2,
								M_TABCLOSE=3,
								M_FONTSERP8X14=4,
								M_VOLATILE_END=5,
								M_BUTTRUN=5,
								M_BUTTSTOP=6,
								M_BUTTQUIT=7,
								M_BUTTMIN=8,
								M_BUTTCREDITS=9,
								M_BUTTARENA=10,
								M_BUTTPLAYER=11,
								M_BUTTOPTIONS=12,
								M_BUTTRMPLAYER=13,
								S_BUTTLOAD=14,
								S_BUTTADD=15,
								S_BUTTOK=16,
								S_BUTTQUIT=17,
								S_BUTTMIN=18,
								S_VSCROLLBUTT=19,
								S_VSCROLL=20,
								S_ARENABG=21,
								S_PLAYERBG=22,
								S_OPTIONSBG=23,
								M_TEXTAREA=24,
								M_TGLBUTT=25,
								UIGRAPHIX_END=26;


    public static final int	F_NORMAL=0,
							F_INACTIVE=1,
							F_RED=2,
							F_GREEN=3,
							F_MARKED=4;

    public static final int ALLIG_LEFT=0,ALLIG_RIGHT=1;
   
    public static final int FIELDELEMSIZE=6;
    public static final int ARENAMAXSIZE=75;
    
    public static final int MONSTARTX=332,MONSTARTY=130;
    public static final int MAXFRAMECOUNT=50;
    
    public static final int
    humanPlayerKeyL[]={KeyEvent.VK_LEFT,	KeyEvent.VK_A, KeyEvent.VK_B, KeyEvent.VK_NUMPAD4},
    humanPlayerKeyU[]={KeyEvent.VK_UP,		KeyEvent.VK_W, KeyEvent.VK_H, KeyEvent.VK_NUMPAD8},
    humanPlayerKeyR[]={KeyEvent.VK_RIGHT,	KeyEvent.VK_D, KeyEvent.VK_M, KeyEvent.VK_NUMPAD6},
    humanPlayerKeyD[]={KeyEvent.VK_DOWN,	KeyEvent.VK_S, KeyEvent.VK_N, KeyEvent.VK_NUMPAD2};

	public static final Color COL_BLUE1=new Color(50,60,120);
	public static final Color COL_BLUE2=new Color(100,111,219);
	public static final Color COL_GREY1=new Color(119,117,120);

	public static final File dir_arena=new File("levels");
	public static final File dir_player=new File("player");
	
    public static final int MAXCOMMANDHIST=8;
    

    
    
}

==> snEADy1.019.zip: src/de/farafin/snEADy/control/GaphixStuff/I_GraphixConstants.java <==
/*
 * Created on 24.02.2005
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
package de.farafin.snEADy.control.GaphixStuff;

 
import java.awt.event.KeyEvent;
import java.io.File;

import de.farafin.snEADy.communication.I_PlayFieldConstants;

/**
 * @author lars & roland
 *
 * TODO To change the template for this generated type comment go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
public interface I_GraphixConstants{
    public static final char    C_NOTHING=0,
								C_WALL=I_PlayFieldConstants.WALL ,
							    C_FLOOR=I_PlayFieldConstants.FREE,
							    C_EXIT=I_PlayFieldConstants.EXIT,
							    C_WALL_S=1,
							    C_WALLCORNER_NW_CC=1,
							    C_WALLCORNER_NW_CV=2,
							    C_WALLCORNER_N=3,
							    C_WALLCORNER_NE_CC=4,
							    C_WALLCORNER_NE_CV=5,
							    C_WALLCORNER_E=6,
							    C_WALLCORNER_SE_CC=7,
							    C_WALLCORNER_SE_CV=8,
							    C_WALLCORNER_S=9,
							    C_WALLCORNER_SW_CC=10,
							    C_WALLCORNER_SW_CV=11,
							    C_WALLCORNER_W=12,
							    C_WALL_E=12,
							    C_PLAYERH_S=13,
							    C_PLAYERH01=13,
							    C_PLAYERH02=14,
							    C_PLAYERH03=15,
							    C_PLAYERH04=16,
							    C_PLAYERH05=17,
							    C_PLAYERH06=18,
							    C_PLAYERH07=19,
							    C_PLAYERH08=20,
							    C_PLAYERH09=21,
							    C_PLAYERH10=22,
							    C_PLAYERH_E=22,
							    C_EXITO=23,
							    C_PLAYER_S=I_PlayFieldConstants.PLAYER_0,
							    C_PLAYER01=I_PlayFieldConstants.PLAYER_0,
							    C_PLAYER02=I_PlayFieldConstants.PLAYER_1,
							    C_PLAYER03=I_PlayFieldConstants.PLAYER_2,
							    C_PLAYER04=I_PlayFieldConstants.PLAYER_3,
							    C_PLAYER05=I_PlayFieldConstants.PLAYER_4,
							    C_PLAYER06=I_PlayFieldConstants.PLAYER_5,
							    C_PLAYER07=I_PlayFieldConstants.PLAYER_6,
							    C_PLAYER08=I_PlayFieldConstants.PLAYER_7,
							    C_PLAYER09=I_PlayFieldConstants.PLAYER_8,
							    C_PLAYER10=I_PlayFieldConstants.PLAYER_9,
							    C_PLAYER_E=I_PlayFieldConstants.PLAYER_9,
							    C_GOODY_S=I_PlayFieldConstants.LENGTH,
							    C_GOODY_SPEED=I_PlayFieldConstants.SPEED,
							    C_GOODY_LENGTH=I_PlayFieldConstants.LENGTH,
							    C_GOODY_POINTS=I_PlayFieldConstants.SHORT,
							    C_GOODY_E=I_PlayFieldConstants.SHORT,
							    C_UNKNOWN=255,
								C_END=256;
	
    public static final char	M_BG=1,
								M_TABOPEN=2,
								M_TABCLOSE=3,
								M_FONTSERP8X14=4,
								M_VOLATILE_END=5,
								M_BUTTRUN=5,
								M_BUTTSTOP=6,
								M_BUTTQUIT=7,
								M_BUTTMIN=8,
								M_BUTTCREDITS=9,
								M_BUTTREPLAY=10,
								M_BUTTARENA=11,
								M_BUTTPLAYER=12,
								M_BUTTOPTIONS=13,
								M_BUTTRMPLAYER=14,
								S_BUTTLOAD=15,
								S_BUTTADD=16,
								S_BUTTEJECT=17,
								S_BUTTOK=18,
								S_BUTTQUIT=19,
								S_BUTTMIN=20,
								S_VSCROLLBUTT=21,
								S_VSCROLL=22,
								S_ARENABG=23,
								S_PLAYERBG=24,
								S_REPLAYBG=25,
								S_OPTIONSBG=26,
								M_TEXTAREA=27,
								M_TGLBUTT=28,
								UIGRAPHIX_END=29;


    public static final int	F_NORMAL=0,
							F_INACTIVE=1,
							F_RED=2,
							F_GREEN=3,
							F_MARKED=4;

    public static final int ALLIG_LEFT=0,ALLIG_RIGHT=1;
   
    public static final int FIELDELEMSIZE=6;
    public static final int ARENAMAXSIZE=75;
    
    public static final int MAXFRAMECOUNT=50;
    
    public static final int
    humanPlayerKeyL[]={KeyEvent.VK_LEFT,	KeyEvent.VK_A, KeyEvent.VK_B, KeyEvent.VK_NUMPAD4},
    humanPlayerKeyU[]={KeyEvent.VK_UP,		KeyEvent.VK_W, KeyEvent.VK_H, KeyEvent.VK_NUMPAD8},
    humanPlayerKeyR[]={KeyEvent.VK_RIGHT,	KeyEvent.VK_D, KeyEvent.VK_M, KeyEvent.VK_NUMPAD6},
    humanPlayerKeyD[]={KeyEvent.VK_DOWN,	KeyEvent.VK_S, KeyEvent.VK_N, KeyEvent.VK_NUMPAD2};

	public static final File dir_arena=new File("levels");
	public static final File dir_player=new File("player");
	public static final File dir_replay=new File("replays");
	public static final File dir_pics=new File("pics");
    
    public static final int
	MONITOR=1,
	PLAYERTAB01=2,
	PLAYERTAB02=3,
	PLAYERTAB03=4,
	PLAYERTAB04=5,
	PLAYERTAB05=6,
	PLAYERTAB06=7,
	PLAYERTAB07=8,
	PLAYERTAB08=9,
	PLAYERTAB09=10,
	PLAYERTAB10=11,
	GAMETIME=12,
	EXITTIME=13,
	SUDDENDTIME=14,
	BUTT_RUN=15,
	BUTT_STOP=16,
	BUTT_MIN=17,
	BUTT_QUIT=18,
	BUTT_REPLAY=19,
	BUTT_ARENA=20,
	BUTT_PLAYER=21,
	BUTT_OPTIONS=22,
	BUTT_CREDITS=23,
	BUTT_RMPLAYER01=24,
	BUTT_RMPLAYER02=25,
	BUTT_RMPLAYER03=26,
	BUTT_RMPLAYER04=27,
	BUTT_RMPLAYER05=28,
	BUTT_RMPLAYER06=29,
	BUTT_RMPLAYER07=30,
	BUTT_RMPLAYER08=31,
	BUTT_RMPLAYER09=32,
	BUTT_RMPLAYER10=33,
	SEL_ARENA=34,
	BUTT_LOADARENA=35,
	BUTT_ARENAOK=36,
	AREA_INFOARENA=37,
	SCROLL_ARENA=38,
	TEXT_HPLAYERNAME=39,
	BUTT_ADDHPLAYER=40,
	BUTT_ADDCPLAYER=41,
	BUTT_PLOK=42,
	SEL_PLAYER=43,
	AREA_INFOPLAYER=44,
	SCROLL_PLAYER=45,
	SEL_REPLAY=46,
	BUTT_LOADREPLAY=47,
	BUTT_EJECTREPLAY=48,
	BUTT_REPLAYOK=49,
	TGL_RECORD=50,
	TGL_REVERSED=51,
	TGL_STEP=52,
	AREA_LOADEDREPLAY=53,
	AREA_INFOREPLAY=54,
	TEXT_RECORDNAME=55,
	TEXT_REPLAYMINCYCLEMS=56,
	TEXT_STEPRANGE=57,
	SCROLL_REPLAY=58,
	TEXT_EXITT=59,
	TEXT_SUDDENDT=60,
	TEXT_ILENGTH=61,
	TEXT_IDELAY=62,
	TEXT_AGROW=63,
	TEXT_ASLOWD=64,
	TEXT_MAXDELAY=65,
	TEXT_PLENGTH=66,
	TEXT_PSPEED=67,
	TEXT_PSLOWD=68,
	TEXT_PPOINTS=69,
	TEXT_MAXTIME=70,
	TEXT_MAXMEM=71,
	TEXT_MINCYCLEMS=72,
	TGL_CONTROLPLAYER=73,
	TGL_TIMEKILL=74,
	TGL_MEMKILL=75,
	TGL_SHOWSC=76,
	TGL_DEBUGMON=77,
	TGL_AUTOGAMESPEED=78,
	TGL_PPTIME=79,
	TGL_PPMEM=80,
	TGL_LOG=81,
	COL_TEXTBGNORMAL=82,
	COL_TEXTBGHIGHLIGHTED=83,
	COL_SCROLLBAR=84,
	SKINSTUFFEND=84;
}
